@@ -28,16 +28,9 @@ namespace Lum {
    */
   class LUMAPI Toolbar : public List
   {
-  public:
-    class Prefs : public Object::Prefs
-    {
-    public:
-      Prefs(const std::wstring& name);
-      void Initialize();
-    };
-
   public:
     Toolbar();
+
     void CalcSize();
     void Layout();
   };
