@@ -198,26 +198,25 @@ namespace Lum {
       ch=std::max(ch,(size_t)texts[x]->GetOMinHeight());
     }
 
-    cw+=OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject);
-    ch+=OS::display->GetSpaceVertical(OS::Display::spaceIntraObject);
-
-    cw=std::max(cw,prevYearButton->GetOMinWidth());
-    cw=std::max(cw,prevMonthButton->GetOMinWidth());
-    cw=std::max(cw,nextMonthButton->GetOMinWidth());
-    cw=std::max(cw,nextYearButton->GetOMinWidth());
-
-    ch=std::max(ch,prevYearButton->GetOMinHeight());
-    ch=std::max(ch,prevMonthButton->GetOMinHeight());
-    ch=std::max(ch,nextMonthButton->GetOMinHeight());
-    ch=std::max(ch,nextYearButton->GetOMinHeight());
-
     current->CalcSize();
 
-    cw=std::max(cw,current->GetOMinWidth()/3);
-    ch=std::max(ch,current->GetOMinHeight());
+    topWidth=prevYearButton->GetOWidth()+prevMonthButton->GetOWidth()+
+             OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)+
+             current->GetOWidth()+
+             OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)+
+             nextYearButton->GetOWidth()+nextMonthButton->GetOWidth();
 
-    minWidth=7*cw;
-    minHeight=8*ch;
+    topHeight=0;
+    topHeight=std::max(topHeight,prevYearButton->GetOHeight());
+    topHeight=std::max(topHeight,prevMonthButton->GetOHeight());
+    topHeight=std::max(topHeight,current->GetOHeight());
+    topHeight=std::max(topHeight,nextMonthButton->GetOHeight());
+    topHeight=std::max(topHeight,nextYearButton->GetOHeight());
+
+    minWidth=std::max(7*cw,topWidth);
+    minHeight=topHeight+
+              OS::display->GetSpaceVertical(OS::Display::spaceIntraObject)+
+              7*ch;
 
     width=minWidth;
     height=minHeight;
@@ -227,22 +226,34 @@ namespace Lum {
 
   void DatePicker::Layout()
   {
-    cw=width / 7;
-    ch=height / 8;
+    cw=width/7;
+    ch=(height-OS::display->GetSpaceVertical(OS::Display::spaceIntraObject)-topHeight)/7;
 
-    current->MoveResize(x+2*cw,y,3*cw,ch);
 
-    prevYearButton->MoveResize(x+0*cw,y,cw,ch);
-    prevMonthButton->MoveResize(x+1*cw,y,cw,ch);
-    nextMonthButton->MoveResize(x+5*cw,y,cw,ch);
-    nextYearButton->MoveResize(x+6*cw,y,cw,ch);
+    prevYearButton->Move(x,y);
+    prevMonthButton->Move(prevYearButton->GetOX()+prevYearButton->GetOWidth(),y);
+
+    nextYearButton->Move(x+width-1-nextYearButton->GetOWidth(),y);
+    nextMonthButton->Move(nextYearButton->GetOX()-nextMonthButton->GetOWidth(),y);
+
+    current->MoveResize(prevMonthButton->GetOX()+
+                        prevMonthButton->GetOWidth()+
+                        OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject),
+                        y+(topHeight-current->GetOHeight())/2,
+                        width-
+                        2*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)-
+                        prevMonthButton->GetOWidth()-
+                        prevYearButton->GetOWidth()-
+                        nextMonthButton->GetOWidth()-
+                        nextYearButton->GetOWidth(),
+                        current->GetOHeight());
 
     for (size_t Y=0; Y<7; Y++) {
       for (size_t X=0; X<7; X++) {
         size_t text=area[X][Y];
 
         if (text!=(size_t)-1) {
-          texts[text]->MoveResize(x+X*cw,y+(Y+1)*ch,cw,ch);
+          texts[text]->MoveResize(x+X*cw,topHeight+OS::display->GetSpaceVertical(OS::Display::spaceIntraObject)+y+Y*ch,cw,ch);
         }
       }
     }
