@@ -141,7 +141,9 @@ namespace Lum {
     }
 
     group=new WindowGroup();
-    if (GetWindow()->GetType()==OS::Window::typeMain && !GetWindow()->IsFullScreen()) {
+    if ((GetWindow()->GetType()==OS::Window::typeMain ||
+         GetWindow()->GetType()==OS::Window::typeDialog) &&
+        !GetWindow()->IsFullScreen()) {
       group->SetBackground(OS::display->GetFill(OS::Display::dialogWindowBackgroundFillIndex));
     }
     else {
