@@ -21,28 +21,38 @@
 #include <Lum/Panel.h>
 #include <Lum/Popup.h>
 #include <Lum/PopupGroup.h>
-#include <Lum/Space.h>
 
 namespace Lum {
   namespace Dlg {
-    class RootsEntry : public Lum::Model::ListTable::Entry
+    struct RootsEntry
     {
-    public:
       std::wstring name;
       std::wstring path;
 
-    public:
-      RootsEntry(Lum::Model::ListTable* table,
-                 const std::wstring& name,
-                 const std::wstring& path)
-      : Lum::Model::ListTable::Entry(table),name(name),path(path)
+      RootsEntry(const std::wstring& name, const std::wstring& path)
+      : name(name),
+        path(path)
       {
         // no code
       }
+    };
 
-      std::wstring GetString(size_t /*column*/) const
+    typedef Model::StdTable<RootsEntry> RootsModel;
+    typedef Base::Reference<RootsModel> RootsModelRef;
+
+    class RootsDataProvider : public RootsModel::DataProvider
+    {
+    public:
+      std::wstring GetString(const RootsModel::Iterator& iter, size_t column) const
       {
-        return name;
+        switch (column) {
+        case 1:
+          return iter->name;
+        case 2:
+          return iter->path;
+        default:
+          assert(false);
+        }
       }
     };
 
@@ -52,13 +62,13 @@ namespace Lum {
       std::wstring                  result;
       Table                         *table;
       Model::SingleLineSelectionRef selection;
-      Model::ListTableRef           roots;
+      RootsModelRef                 roots;
 
     public:
       Locations()
       : table(new Table()),
         selection(new Model::SingleLineSelection),
-        roots(new Model::ListTable(1))
+        roots(new RootsModel(new RootsDataProvider()))
       {
         Observe(table->GetTableView()->GetMouseSelectionAction());
       }
@@ -73,7 +83,7 @@ namespace Lum {
         headerModel->AddColumn(L"",Lum::Base::Size::pixel,0);
 
         for (size_t x=0; x<list.size(); x++) {
-          roots->Append(new RootsEntry(roots,list[x].description,list[x].path));
+          roots->Append(RootsEntry(list[x].description,list[x].path));
         }
 
         table->SetFlex(true,true);
@@ -98,7 +108,7 @@ namespace Lum {
       {
         if (model==table->GetTableView()->GetMouseSelectionAction() && table->GetTableView()->GetMouseSelectionAction()->IsFinished()) {
           if (selection->HasSelection()) {
-            result=dynamic_cast<RootsEntry*>(roots->GetEntry(selection->GetLine()))->path;
+            result=roots->GetEntry(selection->GetLine()).path;
           }
           Exit();
         }
@@ -179,9 +189,9 @@ namespace Lum {
       reloadAction(new Model::Action()),
       parentAction(new Model::Action()),
       fullAction(new Model::Action()),
-      selectionAction(new Model::Action()),
       doubleClickAction(new Model::Action()),
       locationsAction(new Model::Action()),
+      selection(new Model::SingleLineSelection()),
       table(NULL),
       result(false)
     {
@@ -211,9 +221,9 @@ namespace Lum {
       Observe(reloadAction);
       Observe(parentAction);
       Observe(fullAction);
-      Observe(selectionAction);
       Observe(doubleClickAction);
       Observe(locationsAction);
+      Observe(selection);
     }
 
     File::~File()
@@ -238,25 +248,21 @@ namespace Lum {
       return result;
     }
 
-    void File::PreInit()
+    Lum::Object* File::GetContent()
     {
-      Button           *button;
-      ButtonRow        *row;
       DirSelect        *dirSel;
       Menu             *popup;
       Panel            *hPanel,*vPanel;
-      Space            *space;
       Model::HeaderRef header;
 
-      vPanel=new VPanel();
-      vPanel->SetFlex(true,true);
+      vPanel=VPanel::Create(true,true);
 
       dirSel=new DirSelect();
       dirSel->SetFlex(true,false);
       dirSel->SetModel(path);
       vPanel->Add(dirSel);
 
-      vPanel->Add(new VSpace());
+      vPanel->AddSpace();
 
       header=new Model::HeaderImpl();
       header->AddColumn(_l(L"MODEL_DIR_FILENAME",L"Filename"),Base::Size::stdCharWidth,15,true);
@@ -269,8 +275,7 @@ namespace Lum {
       table->SetShowHeader(true);
       table->GetTableView()->SetAutoFitColumns(true);
       table->GetTableView()->SetAutoHSize(true);
-      table->SetSelection(new Model::SingleLineSelection);
-      table->GetTableView()->SetSelectionAction(selectionAction);
+      table->SetSelection(selection);
       table->SetDoubleClickAction(doubleClickAction);
       table->SetFormatProvider(new FileListFormatProvider());
       table->SetModel(dirList);
@@ -282,62 +287,42 @@ namespace Lum {
       table->SetMenu(popup->GetWindow());
 
       vPanel->Add(table);
+      vPanel->AddSpace();
 
-      vPanel->Add(new VSpace());
+      hPanel=HPanel::Create(true,false);
 
-      hPanel=new HPanel();
-      hPanel->SetFlex(true,false);
-
-      locations=new Button();
-      locations->SetFlex(false,true);
-      locations->SetModel(locationsAction);
-      locations->SetText(_l(L"DLG_FILE_LOCATIONS",L"_Locations"));
+      locations=Button::Create(_l(L"DLG_FILE_LOCATIONS",L"_Locations"),locationsAction,false,true);
       hPanel->Add(locations);
-
-      space=new HSpace();
-      space->SetFlex(true,false);
-      hPanel->Add(space);
+      hPanel->AddSpace(true);
 
       if (options->filters.size()>0) {
-        Combo            *combo;
-        Model::ListTable *table;
+        Combo              *combo;
+        Model::StringTable *filters;
 
-        table=new Model::ListTable(1);
+        filters=new Model::StringTable();
         for (size_t x=0; x<options->filters.size(); ++x) {
-          table->AppendString(options->filters[x]->GetName());
+          filters->Append(options->filters[x]->GetName());
         }
 
         combo=new IndexCombo();
         combo->SetWidth(Base::Size::stdCharWidth,15);
         combo->SetModel(filter);
-        combo->SetTableModel(table);
+        combo->SetTableModel(filters);
         hPanel->Add(combo);
       }
 
       vPanel->Add(hPanel);
-      vPanel->Add(new VSpace());
+      vPanel->AddSpace();
 
-      hPanel=new HPanel();
-      hPanel->SetFlex(true,false);
+      hPanel=HPanel::Create(true,false);
 
-      fullStr=new String();
-      fullStr->SetFlex(true,false);
-      fullStr->SetModel(full);
+      fullStr=String::Create(full,true,false);
       fullStr->SetReturnAction(fullAction);
       hPanel->Add(fullStr);
 
-      button=new Button();
-      button->SetFlex(false,true);
-      button->SetModel(reloadAction);
-      button->SetText(_l(L"DLG_FILE_RELOAD",L"_Reload"));
-      hPanel->Add(button);
+      hPanel->Add(Button::Create(_l(L"DLG_FILE_RELOAD",L"_Reload"),reloadAction,false,true));
 
       vPanel->Add(hPanel);
-      vPanel->Add(new VSpace());
-
-      row=ButtonRow::CreateOkCancel(okAction,GetClosedAction());
-      row->SetFlex(true,false);
-      vPanel->Add(row);
 
       if (OS::display->GetSize()<OS::Display::sizeNormal) {
         vPanel->SetMinWidth(Base::Size::workVRel,80);
@@ -346,12 +331,15 @@ namespace Lum {
         vPanel->SetMinHeight(Base::Size::workVRel,60);
       }
 
-      SetMain(vPanel);
-
       RegisterCommitShortcut(table->GetTableView(),okAction);
       RegisterShortcut(table->GetTableView(),0,L"BackSpace",parentAction);
 
-      Dialog::PreInit();
+      return vPanel;
+    }
+
+    void File::GetActions(std::vector<ActionInfo>& actions)
+    {
+      CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
     }
 
     void File::SetPath(const std::wstring& path)
@@ -422,7 +410,9 @@ namespace Lum {
     {
       size_t line;
 
-      if (table->GetTableView()->GetSelection()->HasSelection()) {
+      if (table!=NULL &&
+          table->GetTableView()!=NULL &&
+          table->GetTableView()->GetSelection()->HasSelection()) {
         line=dynamic_cast<Model::SingleLineSelection*>(table->GetTableView()->GetSelection())->GetLine();
 
         dirList->GetEntry(line,entry);
@@ -594,7 +584,7 @@ namespace Lum {
       else if (model==fullAction && fullAction->IsFinished()) {
         HandleChange();
       }
-      else if (model==selectionAction && selectionAction->IsFinished()) {
+      else if (model==selection) {
         OnSelectionChange();
       }
       else if (model==doubleClickAction && doubleClickAction->IsFinished()) {
@@ -628,7 +618,7 @@ namespace Lum {
         }
       }
 
-      Dialog::Resync(model,msg);
+      Dlg::ActionDialog::Resync(model,msg);
     }
 
     std::wstring File::GetPath() const
