@@ -470,8 +470,9 @@ namespace Lum {
         }
       }
 
-      void DrawInfo::PushDash(const char* /*dashList*/, size_t /*len*/, DashMode /*mode*/)
+      void DrawInfo::PushDash(const char* dashList, size_t len, DashMode /*mode*/)
       {
+	assert(dashList!=NULL && len>0);
         /*
         DashEntry entry;
         int       size,cap=CapButt,join=JoinBevel,line=0;
