@@ -1274,10 +1274,12 @@ namespace Lum {
         ++iter) {
       switch (iter->constraint) {
         case constraintMinWidth:
-          oMinWidth=Base::RoundRange(iter->size.GetSize(),oWidth,oMaxWidth);
+          oMinWidth=std::max(oMinWidth,
+                             Base::RoundRange(iter->size.GetSize(),oMinWidth,oMaxWidth));
           break;
         case constraintMinHeight:
-          oMinHeight=Base::RoundRange(iter->size.GetSize(),oHeight,oMaxHeight);
+          oMinHeight=std::max(oMinHeight,
+                              Base::RoundRange(iter->size.GetSize(),oMinHeight,oMaxHeight));
           break;
         default:
           break;
@@ -1289,10 +1291,12 @@ namespace Lum {
         ++iter) {
       switch (iter->constraint) {
         case constraintMaxWidth:
-          oMaxWidth=Base::RoundRange(iter->size.GetSize(),oMinWidth,oMaxWidth);
+          oMaxWidth=std::min(oMaxWidth,
+                             Base::RoundRange(iter->size.GetSize(),oMinWidth,oMaxWidth));
           break;
         case constraintMaxHeight:
-          oMaxHeight=Base::RoundRange(iter->size.GetSize(),oMinHeight,oMaxHeight);
+          oMaxHeight=std::min(oMaxHeight,
+                              Base::RoundRange(iter->size.GetSize(),oMinHeight,oMaxHeight));
           break;
         default:
           break;
@@ -1337,7 +1341,6 @@ namespace Lum {
       maxHeight=oMaxHeight;
     }
 
-
     if (!horizontalFlex) {
       oMinWidth=oWidth;
       minWidth=width;
@@ -2323,7 +2326,8 @@ namespace Lum {
   }
   void Scrollable::Resync(Base::Model* model, const Base::ResyncMsg& msg)
   {
-    if (model==updateDimensionsAction && updateDimensionsAction->IsFinished()) {
+    if (model==updateDimensionsAction &&
+        updateDimensionsAction->IsFinished()) {
       UpdateDimensions();
     }
   }
