@@ -30,23 +30,20 @@ namespace Lum {
   HSpace::HSpace(Size size, bool flex)
   : Space(size)
   {
-    if (flex) {
-      SetFlex(true,false);
-    }
+    SetFlex(flex,false);
   }
 
   HSpace::HSpace(bool flex)
   : Space(sizeNormal)
   {
-    if (flex) {
-      SetFlex(true,false);
-    }
+    SetFlex(flex,false);
   }
 
   void HSpace::CalcSize()
   {
     width=0;
     height=0;
+    minHeight=0;
 
     switch (size) {
     case sizeEmpty:
@@ -79,22 +76,19 @@ namespace Lum {
   VSpace::VSpace(Size size, bool flex)
   : Space(size)
   {
-    if (flex) {
-      SetFlex(false,true);
-    }
+    SetFlex(false,flex);
   }
 
   VSpace::VSpace(bool flex)
   : Space(sizeNormal)
   {
-    if (flex) {
-      SetFlex(false,true);
-    }
+    SetFlex(false,flex);
   }
 
   void VSpace::CalcSize()
   {
     width=0;
+    minWidth=0;
     height=0;
 
     switch (size) {
@@ -124,5 +118,4 @@ namespace Lum {
 
     Object::CalcSize();
   }
-
 }
