@@ -452,8 +452,10 @@ namespace Lum {
 
   void TableView::UpdateDimensions()
   {
-    if (model.Valid() && !model->IsNull() &&
-        (model->GetRows()>0 || (header.Valid() && header->GetColumns()>1))) {
+    if (model.Valid() &&
+        !model->IsNull() &&
+        (model->GetRows()>0 ||
+         (header.Valid() && header->GetColumns()>1))) {
       hAdjustment->SetStepSize(font->StringWidth(L"m"));
       hAdjustment->SetDimension(width,tableWidth);
     }
@@ -461,7 +463,9 @@ namespace Lum {
       hAdjustment->SetInvalid();
     }
 
-    if (model.Valid() && !model->IsNull() && model->GetRows()>0) {
+    if (model.Valid() &&
+        !model->IsNull() &&
+        model->GetRows()>0) {
       if (rowHeight!=0) {
         vAdjustment->SetStepSize(rowHeight);
         vAdjustment->SetDimension(height,model->GetRows()*rowHeight);
@@ -1207,7 +1211,8 @@ namespace Lum {
     }
     else { // unknown/empty message
       if (model==this->model) {
-        if (selection.Valid() && selection->HasSelection()) {
+        if (selection.Valid() &&
+            selection->HasSelection()) {
           selection->OnClear();
         }
 
